==> HorsePower-1.11.2-1.1.2.7-sources.jar: se/gory_moon/horsepower/tileentity/TileEntityFiller.java <==
package se.gory_moon.horsepower.tileentity;

import net.minecraft.block.BlockDirectional;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.ISidedInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.text.ITextComponent;

public class TileEntityFiller extends TileEntity implements ISidedInventory {

    private TileEntityHPBase getFilledTileEntity() {
        EnumFacing facing = func_145831_w().func_180495_p(func_174877_v()).func_177229_b(BlockDirectional.field_176387_N);
        TileEntity tileEntity = func_145831_w().func_175625_s(field_174879_c.func_177972_a(facing));
        if (tileEntity instanceof TileEntityHPBase) {
            return (TileEntityHPBase) tileEntity;
        }
        return null;
    }

    @Override
    public int[] func_180463_a(EnumFacing side) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_180463_a(side);
        return new int[0];
    }

    @Override
    public boolean func_180462_a(int index, ItemStack itemStackIn, EnumFacing direction) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_180462_a(index, itemStackIn, direction);
        return false;
    }

    @Override
    public boolean func_180461_b(int index, ItemStack stack, EnumFacing direction) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_180461_b(index, stack, direction);
        return false;
    }

    @Override
    public int func_70302_i_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70302_i_();
        return 0;
    }

    @Override
    public boolean func_191420_l() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_191420_l();
        return false;
    }

    @Override
    public ItemStack func_70301_a(int index) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70301_a(index);
        return null;
    }

    @Override
    public ItemStack func_70298_a(int index, int count) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70298_a(index, count);
        return null;
    }

    @Override
    public ItemStack func_70304_b(int index) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70304_b(index);
        return null;
    }

    @Override
    public void func_70299_a(int index, ItemStack stack) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_70299_a(index, stack);
    }

    @Override
    public int func_70297_j_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70297_j_();
        return 0;
    }

    @Override
    public void func_70296_d() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_70296_d();
        super.func_70296_d();
    }

    @Override
    public boolean func_70300_a(EntityPlayer player) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_70300_a(player);
        return false;
    }

    @Override
    public void func_174889_b(EntityPlayer player) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_174889_b(player);
    }

    @Override
    public void func_174886_c(EntityPlayer player) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_174886_c(player);
    }

    @Override
    public boolean func_94041_b(int index, ItemStack stack) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_94041_b(index, stack);
        return false;
    }

    @Override
    public int func_174887_a_(int id) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return func_174887_a_(id);
        return 0;
    }

    @Override
    public void func_174885_b(int id, int value) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_174885_b(id, value);
    }

    @Override
    public int func_174890_g() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_174890_g();
        return 0;
    }

    @Override
    public void func_174888_l() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_174888_l();
    }

    @Override
    public String func_70005_c_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70005_c_();
        return null;
    }

    @Override
    public boolean func_145818_k_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_145818_k_();
        return false;
    }

    @Override
    public ITextComponent func_145748_c_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_145748_c_();
        return null;
    }

    @SuppressWarnings("unchecked")
    @Override
    public <T> T getCapability(net.minecraftforge.common.capabilities.Capability<T> capability, @javax.annotation.Nullable net.minecraft.util.EnumFacing facing) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.getCapability(capability, facing);
        return super.getCapability(capability, facing);
    }
}

==> HorsePower-1.11.2-1.1.2.8-sources.jar: se/gory_moon/horsepower/tileentity/TileEntityFiller.java <==
package se.gory_moon.horsepower.tileentity;

import net.minecraft.block.BlockDirectional;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.ISidedInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.text.ITextComponent;

public class TileEntityFiller extends TileEntity implements ISidedInventory {

    private TileEntityHPBase getFilledTileEntity() {
        BlockPos pos = getFilledPos();
        TileEntity tileEntity = func_145831_w().func_175625_s(pos);
        if (tileEntity instanceof TileEntityHPBase) {
            return (TileEntityHPBase) tileEntity;
        }
        return null;
    }

    public BlockPos getFilledPos() {
        EnumFacing facing = func_145831_w().func_180495_p(func_174877_v()).func_177229_b(BlockDirectional.field_176387_N);
        return field_174879_c.func_177972_a(facing);
    }

    @Override
    public int[] func_180463_a(EnumFacing side) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_180463_a(side);
        return new int[0];
    }

    @Override
    public boolean func_180462_a(int index, ItemStack itemStackIn, EnumFacing direction) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_180462_a(index, itemStackIn, direction);
        return false;
    }

    @Override
    public boolean func_180461_b(int index, ItemStack stack, EnumFacing direction) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_180461_b(index, stack, direction);
        return false;
    }

    @Override
    public int func_70302_i_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70302_i_();
        return 0;
    }

    @Override
    public boolean func_191420_l() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_191420_l();
        return false;
    }

    @Override
    public ItemStack func_70301_a(int index) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70301_a(index);
        return null;
    }

    @Override
    public ItemStack func_70298_a(int index, int count) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70298_a(index, count);
        return null;
    }

    @Override
    public ItemStack func_70304_b(int index) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70304_b(index);
        return null;
    }

    @Override
    public void func_70299_a(int index, ItemStack stack) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_70299_a(index, stack);
    }

    @Override
    public int func_70297_j_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70297_j_();
        return 0;
    }

    @Override
    public void func_70296_d() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_70296_d();
        super.func_70296_d();
    }

    @Override
    public boolean func_70300_a(EntityPlayer player) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_70300_a(player);
        return false;
    }

    @Override
    public void func_174889_b(EntityPlayer player) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_174889_b(player);
    }

    @Override
    public void func_174886_c(EntityPlayer player) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_174886_c(player);
    }

    @Override
    public boolean func_94041_b(int index, ItemStack stack) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_94041_b(index, stack);
        return false;
    }

    @Override
    public int func_174887_a_(int id) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return func_174887_a_(id);
        return 0;
    }

    @Override
    public void func_174885_b(int id, int value) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_174885_b(id, value);
    }

    @Override
    public int func_174890_g() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_174890_g();
        return 0;
    }

    @Override
    public void func_174888_l() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            te.func_174888_l();
    }

    @Override
    public String func_70005_c_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_70005_c_();
        return null;
    }

    @Override
    public boolean func_145818_k_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_145818_k_();
        return false;
    }

    @Override
    public ITextComponent func_145748_c_() {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.func_145748_c_();
        return null;
    }

    @SuppressWarnings("unchecked")
    @Override
    public <T> T getCapability(net.minecraftforge.common.capabilities.Capability<T> capability, @javax.annotation.Nullable net.minecraft.util.EnumFacing facing) {
        TileEntityHPBase te = getFilledTileEntity();
        if (te != null)
            return te.getCapability(capability, facing);
        return super.getCapability(capability, facing);
    }
}
